import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ConditionalAccessPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#display_name ConditionalAccessPolicy#display_name}.
     *
     * @stability stable
     */
    readonly displayName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#state ConditionalAccessPolicy#state}.
     *
     * @stability stable
     */
    readonly state: string;
    /**
     * conditions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#conditions ConditionalAccessPolicy#conditions}
     *
     * @stability stable
     */
    readonly conditions: ConditionalAccessPolicyConditions;
    /**
     * grant_controls block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#grant_controls ConditionalAccessPolicy#grant_controls}
     *
     * @stability stable
     */
    readonly grantControls: ConditionalAccessPolicyGrantControls;
    /**
     * session_controls block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#session_controls ConditionalAccessPolicy#session_controls}
     *
     * @stability stable
     */
    readonly sessionControls?: ConditionalAccessPolicySessionControls;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#timeouts ConditionalAccessPolicy#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ConditionalAccessPolicyTimeouts;
}
/**
 * @stability stable
 */
export interface ConditionalAccessPolicyConditionsApplications {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#excluded_applications ConditionalAccessPolicy#excluded_applications}.
     *
     * @stability stable
     */
    readonly excludedApplications?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#included_applications ConditionalAccessPolicy#included_applications}.
     *
     * @stability stable
     */
    readonly includedApplications: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#included_user_actions ConditionalAccessPolicy#included_user_actions}.
     *
     * @stability stable
     */
    readonly includedUserActions?: string[];
}
/**
 * @stability stable
 */
export declare class ConditionalAccessPolicyConditionsApplicationsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _excludedApplications?;
    /**
     * @stability stable
     */
    get excludedApplications(): string[] | undefined;
    /**
     * @stability stable
     */
    set excludedApplications(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetExcludedApplications(): void;
    /**
     * @stability stable
     */
    get excludedApplicationsInput(): string[] | undefined;
    private _includedApplications?;
    /**
     * @stability stable
     */
    get includedApplications(): string[];
    /**
     * @stability stable
     */
    set includedApplications(value: string[]);
    /**
     * @stability stable
     */
    get includedApplicationsInput(): string[] | undefined;
    private _includedUserActions?;
    /**
     * @stability stable
     */
    get includedUserActions(): string[] | undefined;
    /**
     * @stability stable
     */
    set includedUserActions(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetIncludedUserActions(): void;
    /**
     * @stability stable
     */
    get includedUserActionsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface ConditionalAccessPolicyConditionsLocations {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#excluded_locations ConditionalAccessPolicy#excluded_locations}.
     *
     * @stability stable
     */
    readonly excludedLocations?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#included_locations ConditionalAccessPolicy#included_locations}.
     *
     * @stability stable
     */
    readonly includedLocations: string[];
}
/**
 * @stability stable
 */
export declare class ConditionalAccessPolicyConditionsLocationsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _excludedLocations?;
    /**
     * @stability stable
     */
    get excludedLocations(): string[] | undefined;
    /**
     * @stability stable
     */
    set excludedLocations(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetExcludedLocations(): void;
    /**
     * @stability stable
     */
    get excludedLocationsInput(): string[] | undefined;
    private _includedLocations?;
    /**
     * @stability stable
     */
    get includedLocations(): string[];
    /**
     * @stability stable
     */
    set includedLocations(value: string[]);
    /**
     * @stability stable
     */
    get includedLocationsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface ConditionalAccessPolicyConditionsPlatforms {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#excluded_platforms ConditionalAccessPolicy#excluded_platforms}.
     *
     * @stability stable
     */
    readonly excludedPlatforms?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#included_platforms ConditionalAccessPolicy#included_platforms}.
     *
     * @stability stable
     */
    readonly includedPlatforms: string[];
}
/**
 * @stability stable
 */
export declare class ConditionalAccessPolicyConditionsPlatformsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _excludedPlatforms?;
    /**
     * @stability stable
     */
    get excludedPlatforms(): string[] | undefined;
    /**
     * @stability stable
     */
    set excludedPlatforms(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetExcludedPlatforms(): void;
    /**
     * @stability stable
     */
    get excludedPlatformsInput(): string[] | undefined;
    private _includedPlatforms?;
    /**
     * @stability stable
     */
    get includedPlatforms(): string[];
    /**
     * @stability stable
     */
    set includedPlatforms(value: string[]);
    /**
     * @stability stable
     */
    get includedPlatformsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface ConditionalAccessPolicyConditionsUsers {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#excluded_groups ConditionalAccessPolicy#excluded_groups}.
     *
     * @stability stable
     */
    readonly excludedGroups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#excluded_roles ConditionalAccessPolicy#excluded_roles}.
     *
     * @stability stable
     */
    readonly excludedRoles?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#excluded_users ConditionalAccessPolicy#excluded_users}.
     *
     * @stability stable
     */
    readonly excludedUsers?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#included_groups ConditionalAccessPolicy#included_groups}.
     *
     * @stability stable
     */
    readonly includedGroups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#included_roles ConditionalAccessPolicy#included_roles}.
     *
     * @stability stable
     */
    readonly includedRoles?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#included_users ConditionalAccessPolicy#included_users}.
     *
     * @stability stable
     */
    readonly includedUsers?: string[];
}
/**
 * @stability stable
 */
export declare class ConditionalAccessPolicyConditionsUsersOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _excludedGroups?;
    /**
     * @stability stable
     */
    get excludedGroups(): string[] | undefined;
    /**
     * @stability stable
     */
    set excludedGroups(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetExcludedGroups(): void;
    /**
     * @stability stable
     */
    get excludedGroupsInput(): string[] | undefined;
    private _excludedRoles?;
    /**
     * @stability stable
     */
    get excludedRoles(): string[] | undefined;
    /**
     * @stability stable
     */
    set excludedRoles(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetExcludedRoles(): void;
    /**
     * @stability stable
     */
    get excludedRolesInput(): string[] | undefined;
    private _excludedUsers?;
    /**
     * @stability stable
     */
    get excludedUsers(): string[] | undefined;
    /**
     * @stability stable
     */
    set excludedUsers(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetExcludedUsers(): void;
    /**
     * @stability stable
     */
    get excludedUsersInput(): string[] | undefined;
    private _includedGroups?;
    /**
     * @stability stable
     */
    get includedGroups(): string[] | undefined;
    /**
     * @stability stable
     */
    set includedGroups(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetIncludedGroups(): void;
    /**
     * @stability stable
     */
    get includedGroupsInput(): string[] | undefined;
    private _includedRoles?;
    /**
     * @stability stable
     */
    get includedRoles(): string[] | undefined;
    /**
     * @stability stable
     */
    set includedRoles(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetIncludedRoles(): void;
    /**
     * @stability stable
     */
    get includedRolesInput(): string[] | undefined;
    private _includedUsers?;
    /**
     * @stability stable
     */
    get includedUsers(): string[] | undefined;
    /**
     * @stability stable
     */
    set includedUsers(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetIncludedUsers(): void;
    /**
     * @stability stable
     */
    get includedUsersInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface ConditionalAccessPolicyConditions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#client_app_types ConditionalAccessPolicy#client_app_types}.
     *
     * @stability stable
     */
    readonly clientAppTypes: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#sign_in_risk_levels ConditionalAccessPolicy#sign_in_risk_levels}.
     *
     * @stability stable
     */
    readonly signInRiskLevels?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#user_risk_levels ConditionalAccessPolicy#user_risk_levels}.
     *
     * @stability stable
     */
    readonly userRiskLevels?: string[];
    /**
     * applications block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#applications ConditionalAccessPolicy#applications}
     *
     * @stability stable
     */
    readonly applications: ConditionalAccessPolicyConditionsApplications;
    /**
     * locations block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#locations ConditionalAccessPolicy#locations}
     *
     * @stability stable
     */
    readonly locations: ConditionalAccessPolicyConditionsLocations;
    /**
     * platforms block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#platforms ConditionalAccessPolicy#platforms}
     *
     * @stability stable
     */
    readonly platforms: ConditionalAccessPolicyConditionsPlatforms;
    /**
     * users block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#users ConditionalAccessPolicy#users}
     *
     * @stability stable
     */
    readonly users: ConditionalAccessPolicyConditionsUsers;
}
/**
 * @stability stable
 */
export declare class ConditionalAccessPolicyConditionsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _clientAppTypes?;
    /**
     * @stability stable
     */
    get clientAppTypes(): string[];
    /**
     * @stability stable
     */
    set clientAppTypes(value: string[]);
    /**
     * @stability stable
     */
    get clientAppTypesInput(): string[] | undefined;
    private _signInRiskLevels?;
    /**
     * @stability stable
     */
    get signInRiskLevels(): string[] | undefined;
    /**
     * @stability stable
     */
    set signInRiskLevels(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetSignInRiskLevels(): void;
    /**
     * @stability stable
     */
    get signInRiskLevelsInput(): string[] | undefined;
    private _userRiskLevels?;
    /**
     * @stability stable
     */
    get userRiskLevels(): string[] | undefined;
    /**
     * @stability stable
     */
    set userRiskLevels(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetUserRiskLevels(): void;
    /**
     * @stability stable
     */
    get userRiskLevelsInput(): string[] | undefined;
    private _applications?;
    private __applicationsOutput;
    /**
     * @stability stable
     */
    get applications(): ConditionalAccessPolicyConditionsApplicationsOutputReference;
    /**
     * @stability stable
     */
    putApplications(value: ConditionalAccessPolicyConditionsApplications): void;
    /**
     * @stability stable
     */
    get applicationsInput(): ConditionalAccessPolicyConditionsApplications | undefined;
    private _locations?;
    private __locationsOutput;
    /**
     * @stability stable
     */
    get locations(): ConditionalAccessPolicyConditionsLocationsOutputReference;
    /**
     * @stability stable
     */
    putLocations(value: ConditionalAccessPolicyConditionsLocations): void;
    /**
     * @stability stable
     */
    get locationsInput(): ConditionalAccessPolicyConditionsLocations | undefined;
    private _platforms?;
    private __platformsOutput;
    /**
     * @stability stable
     */
    get platforms(): ConditionalAccessPolicyConditionsPlatformsOutputReference;
    /**
     * @stability stable
     */
    putPlatforms(value: ConditionalAccessPolicyConditionsPlatforms): void;
    /**
     * @stability stable
     */
    get platformsInput(): ConditionalAccessPolicyConditionsPlatforms | undefined;
    private _users?;
    private __usersOutput;
    /**
     * @stability stable
     */
    get users(): ConditionalAccessPolicyConditionsUsersOutputReference;
    /**
     * @stability stable
     */
    putUsers(value: ConditionalAccessPolicyConditionsUsers): void;
    /**
     * @stability stable
     */
    get usersInput(): ConditionalAccessPolicyConditionsUsers | undefined;
}
/**
 * @stability stable
 */
export interface ConditionalAccessPolicyGrantControls {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#built_in_controls ConditionalAccessPolicy#built_in_controls}.
     *
     * @stability stable
     */
    readonly builtInControls: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#custom_authentication_factors ConditionalAccessPolicy#custom_authentication_factors}.
     *
     * @stability stable
     */
    readonly customAuthenticationFactors?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#operator ConditionalAccessPolicy#operator}.
     *
     * @stability stable
     */
    readonly operator: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#terms_of_use ConditionalAccessPolicy#terms_of_use}.
     *
     * @stability stable
     */
    readonly termsOfUse?: string[];
}
/**
 * @stability stable
 */
export declare class ConditionalAccessPolicyGrantControlsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _builtInControls?;
    /**
     * @stability stable
     */
    get builtInControls(): string[];
    /**
     * @stability stable
     */
    set builtInControls(value: string[]);
    /**
     * @stability stable
     */
    get builtInControlsInput(): string[] | undefined;
    private _customAuthenticationFactors?;
    /**
     * @stability stable
     */
    get customAuthenticationFactors(): string[] | undefined;
    /**
     * @stability stable
     */
    set customAuthenticationFactors(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetCustomAuthenticationFactors(): void;
    /**
     * @stability stable
     */
    get customAuthenticationFactorsInput(): string[] | undefined;
    private _operator?;
    /**
     * @stability stable
     */
    get operator(): string;
    /**
     * @stability stable
     */
    set operator(value: string);
    /**
     * @stability stable
     */
    get operatorInput(): string | undefined;
    private _termsOfUse?;
    /**
     * @stability stable
     */
    get termsOfUse(): string[] | undefined;
    /**
     * @stability stable
     */
    set termsOfUse(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetTermsOfUse(): void;
    /**
     * @stability stable
     */
    get termsOfUseInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface ConditionalAccessPolicySessionControls {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#application_enforced_restrictions_enabled ConditionalAccessPolicy#application_enforced_restrictions_enabled}.
     *
     * @stability stable
     */
    readonly applicationEnforcedRestrictionsEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#cloud_app_security_policy ConditionalAccessPolicy#cloud_app_security_policy}.
     *
     * @stability stable
     */
    readonly cloudAppSecurityPolicy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#sign_in_frequency ConditionalAccessPolicy#sign_in_frequency}.
     *
     * @stability stable
     */
    readonly signInFrequency?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#sign_in_frequency_period ConditionalAccessPolicy#sign_in_frequency_period}.
     *
     * @stability stable
     */
    readonly signInFrequencyPeriod?: string;
}
/**
 * @stability stable
 */
export declare class ConditionalAccessPolicySessionControlsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _applicationEnforcedRestrictionsEnabled?;
    /**
     * @stability stable
     */
    get applicationEnforcedRestrictionsEnabled(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set applicationEnforcedRestrictionsEnabled(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetApplicationEnforcedRestrictionsEnabled(): void;
    /**
     * @stability stable
     */
    get applicationEnforcedRestrictionsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _cloudAppSecurityPolicy?;
    /**
     * @stability stable
     */
    get cloudAppSecurityPolicy(): string | undefined;
    /**
     * @stability stable
     */
    set cloudAppSecurityPolicy(value: string | undefined);
    /**
     * @stability stable
     */
    resetCloudAppSecurityPolicy(): void;
    /**
     * @stability stable
     */
    get cloudAppSecurityPolicyInput(): string | undefined;
    private _signInFrequency?;
    /**
     * @stability stable
     */
    get signInFrequency(): number | undefined;
    /**
     * @stability stable
     */
    set signInFrequency(value: number | undefined);
    /**
     * @stability stable
     */
    resetSignInFrequency(): void;
    /**
     * @stability stable
     */
    get signInFrequencyInput(): number | undefined;
    private _signInFrequencyPeriod?;
    /**
     * @stability stable
     */
    get signInFrequencyPeriod(): string | undefined;
    /**
     * @stability stable
     */
    set signInFrequencyPeriod(value: string | undefined);
    /**
     * @stability stable
     */
    resetSignInFrequencyPeriod(): void;
    /**
     * @stability stable
     */
    get signInFrequencyPeriodInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ConditionalAccessPolicyTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#create ConditionalAccessPolicy#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#delete ConditionalAccessPolicy#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#read ConditionalAccessPolicy#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html#update ConditionalAccessPolicy#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ConditionalAccessPolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string | undefined;
    /**
     * @stability stable
     */
    set create(value: string | undefined);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string | undefined;
    /**
     * @stability stable
     */
    set delete(value: string | undefined);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _read?;
    /**
     * @stability stable
     */
    get read(): string | undefined;
    /**
     * @stability stable
     */
    set read(value: string | undefined);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string | undefined;
    /**
     * @stability stable
     */
    set update(value: string | undefined);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html azuread_conditional_access_policy}.
 *
 * @stability stable
 */
export declare class ConditionalAccessPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azuread/r/conditional_access_policy.html azuread_conditional_access_policy} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ConditionalAccessPolicyConfig);
    private _displayName?;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    set displayName(value: string);
    /**
     * @stability stable
     */
    get displayNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _state?;
    /**
     * @stability stable
     */
    get state(): string;
    /**
     * @stability stable
     */
    set state(value: string);
    /**
     * @stability stable
     */
    get stateInput(): string | undefined;
    private _conditions?;
    private __conditionsOutput;
    /**
     * @stability stable
     */
    get conditions(): ConditionalAccessPolicyConditionsOutputReference;
    /**
     * @stability stable
     */
    putConditions(value: ConditionalAccessPolicyConditions): void;
    /**
     * @stability stable
     */
    get conditionsInput(): ConditionalAccessPolicyConditions | undefined;
    private _grantControls?;
    private __grantControlsOutput;
    /**
     * @stability stable
     */
    get grantControls(): ConditionalAccessPolicyGrantControlsOutputReference;
    /**
     * @stability stable
     */
    putGrantControls(value: ConditionalAccessPolicyGrantControls): void;
    /**
     * @stability stable
     */
    get grantControlsInput(): ConditionalAccessPolicyGrantControls | undefined;
    private _sessionControls?;
    private __sessionControlsOutput;
    /**
     * @stability stable
     */
    get sessionControls(): ConditionalAccessPolicySessionControlsOutputReference;
    /**
     * @stability stable
     */
    putSessionControls(value: ConditionalAccessPolicySessionControls | undefined): void;
    /**
     * @stability stable
     */
    resetSessionControls(): void;
    /**
     * @stability stable
     */
    get sessionControlsInput(): ConditionalAccessPolicySessionControls | undefined;
    private _timeouts?;
    private __timeoutsOutput;
    /**
     * @stability stable
     */
    get timeouts(): ConditionalAccessPolicyTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: ConditionalAccessPolicyTimeouts | undefined): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ConditionalAccessPolicyTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
